<?php
if ( ! class_exists( 'IPScarcityPlus_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPScarcityPlus_Admin
    {
        /**
         * Show content admin home
         *
         * @return void
         */
        public function index()
        {
        ?>
            <div class="wrap">
                <div id="icon-page-ipscarcityplus" class="icon32">
                    <br>
                </div>
                <h2>
                    <?php echo IPSCARCITYPLUS_TITLE; ?>
                    <a class="add-new-h2" href="admin.php?page=wp-scarcityplus-add" title="Add Countdown">Add New</a>
                </h2>
                <div id="ipsp_messages"></div>
                
                <?php
                require_once( plugin_dir_path( __FILE__ ) . "list-table.php" );
                $paginArgs = array(
                    "per_page" => 20 
                );
                $listTable = new IPScarcityPlus_ListTable();
                $listTable->prepare_items();
                $listTable->display();
                ?>
                
            </div>
        <?php
        }
        
        /**
         * Show content for meta box
         *
         * @return void
         */
        public function metaBox( $post )
        {
        ?>
            <div id="ip_metaBoxCountdown">
                <p><strong><?php _e( 'Countdown' ); ?></strong></p>
                <label for="ip_countdownSelect" class="screen-reader-text"><?php _e( 'Countdown' ); ?></label>
                <select id="ip_countdownSelect" name="ip_countdown_select">
                    <option value="">None</option>
                    <?php
                    $args = array(
                        'orderby'     => 'post_date',
                        'order'       => 'DESC', 
                        'post_type'   => 'ipcountdown',
                        'post_status' => array(1)
                    );
                    $query   = new WP_Query;
                    $cdowns  = $query->query( $args );
                    $metas   = (array)get_post_meta( $post->ID, '_ip_post_countdown' );
                    $cdownId = $pos = 0;
                    if ( ! empty( $metas )) {
                        $meta = array_shift( $metas );
                        if ( isset( $meta['countdown_id'] )) {
                            $cdownId = $meta['countdown_id'];
                        }
                        if ( isset( $meta['position'] )) {
                            $pos = $meta['position'];
                        }
                    }
                    if ( ! empty( $cdowns )) {
                        foreach( $cdowns as $cdown ) {
                            $selected = '';
                            if ( $cdown->ID == $cdownId ) {
                                $selected = ' selected="selected"';
                            }
                            echo '<option' . $selected . ' value="' . $cdown->ID . '">' . $cdown->post_title . '</option>';
                        }
                    }
                    ?>
                </select>
                <p><strong><?php _e( 'Position' ); ?></strong></p>
                <label for="ip_countdownPosition" class="screen-reader-text"><?php _e( 'Position' ); ?></label>
                <select id="ip_countdownPosition" name="ip_countdown_position">
                    <?php
                    $positions = array(
                        1 => 'Top Center',
                        2 => 'Top Left',
                        3 => 'Top Right',
                        4 => 'Bottom Center',
                        5 => 'Bottom Left',
                        6 => 'Bottom Right',
                    );
                    foreach( $positions as $id => $label ) {
                        $selected = '';
                        if ( $id == $pos ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $id . '">' . $label . '</option>';
                    }
                    ?>
                </select>
                <?php wp_nonce_field( plugin_basename( __FILE__ ), 'ip_select_countdown_nonce' ); ?>
            </div>
        <?php
        }
        
        /**
         * Show content admin for setting countdown in homepage
         *
         * @return void
         */
        public function adminHome()
        {
            $submit  = false;
            $success = true;
            if ( isset( $_POST['ip_countdown_select'] )) {
                $submit  = true;
                $cdid    = absint( $_POST['ip_countdown_select'] );
                $cdpos   = absint( $_POST['ip_countdown_position'] );
                $opts    = array(
                    'countdown_id'  => $cdid,
                    'position'      => $cdpos
                );
                $success = update_option( '_ip_homepage_countdown', $opts );
            }
        ?>
            <div class="wrap">
                <div id="icon-page-ipscarcityplus" class="icon32">
                    <br>
                </div>
                <h2><?php _e( 'Countdown Settings' ); ?></h2>
                
                <?php
                if ( $submit ) {
                    echo '<div id="messages" class="updated"><p>' . __( 'Successfully set Countdown for homepage' ) . '</p></div>';
                }
                ?>
                
                <div id="ip_countdownHomepage">
                    <form id="ip_countdownHomeForm" method="post" action="">
                        <table class="form-table">
                            <tbody>
                                <tr valign="top">
                                    <th scope="row">
                                        <label for="ip_countdownSelect"><?php _e( 'Select Countdown' ); ?></label>
                                    </th>
                                    <td>
                                        <select id="ip_countdownSelect" name="ip_countdown_select">
                                            <option value="">None</option>
                                            <?php
                                            $args = array(
                                                'orderby'     => 'post_date',
                                                'order'       => 'DESC', 
                                                'post_type'   => 'ipcountdown',
                                                'post_status' => array(1)
                                            );
                                            $opts  = get_option( '_ip_homepage_countdown' );
                                            $query = new WP_Query;
                                            $countdowns = $query->query( $args );
                                            if ( ! empty( $countdowns )) {
                                                foreach( $countdowns as $countdown ) {
                                                    $selected = '';
                                                    if ( $countdown->ID == $opts['countdown_id'] ) {
                                                        $selected = ' selected="selected"';
                                                    }
                                                    echo '<option' . $selected . ' value="' . $countdown->ID . '">' . $countdown->post_title . '</option>';
                                                }
                                            }
                                            ?>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign="top">
                                    <th scope="row">
                                        <label for="ip_countdownPosition"><?php _e( 'Position' ); ?></label>
                                    </th>
                                    <td>
                                        <select id="ip_countdownPosition" name="ip_countdown_position">
                                            <?php
                                            $positions = array(
                                                1 => 'Top Center',
                                                2 => 'Top Left',
                                                3 => 'Top Right',
                                                4 => 'Bottom Center',
                                                5 => 'Bottom Left',
                                                6 => 'Bottom Right',
                                            );
                                            foreach( $positions as $id => $label ) {
                                                $selected = '';
                                                if ( $id == $opts['position'] ) {
                                                    $selected = ' selected="selected"';
                                                }
                                                echo '<option' . $selected . ' value="' . $id . '">' . $label . '</option>';
                                            }
                                            ?>
                                        </select>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <div class="buttons">
                            <input type="submit" class="button button-primary button-large" id="ip_doHomeCountdown" name="ip_doHomeCountdown" value="Set Countdown" />
                        </div>
                    </form>
                </div>
            </div>
        <?php
        }
        
        /**
         * Show content admin edit
         *
         * @return void
         */
        public function edit()
        {
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $countdown = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?') );
            }
            $this->manage( $countdown );
        }
        
        /**
         * Show content admin manage
         *
         * @return void
         */
        public function manage( $countdown = false )
        {
            $id = 0;
            if ( $countdown ) {
                $id = $countdown->ID;
            }
            $setting = new IPScarcityPlus_Setting( $id );
            
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
        ?>
            <div class="wrap">
                <div id="icon-page-ipscarcityplus" class="icon32">
                    <br>
                </div>
                <?php
                if ( $countdown ) :
                ?>
                    <h2><?php _e( 'Edit Countdown' ); ?></h2>
                <?php 
                else :
                ?>
                    <h2><?php _e( 'Add Countdown' ); ?></h2>
                <?php
                endif;
                ?>
                <div id="ipsp_messages"></div>
                
                <div class="ipsp-main">
                <form id="ipsp-manage-form" action="" method="post">
                    
                    <input type="hidden" id="ipsp-countdown-id" name="countdown_id" value="<?php echo $id; ?>" />
                    
                    <div class="ipsp-button-preview">
                        <a id="ipsp-modal-preview" class="button button-large" href="#" title="Countdown Preview"><?php _e( 'Preview' ); ?></a>
                    </div>
                    
                    <div class="ipsp-section">
                        <h3><?php _e( 'General' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-icd-name"><?php _e( 'Name' ); ?></label>
                                <div class="ipsp-input">
                                    <?php
                                    $name = '';
                                    if ( $countdown ) {
                                        $name = $countdown->post_title;
                                    }
                                    ?>
                                    <input type="text" name="countdown_name" id="ipsp-icd-name" value="<?php echo $name; ?>" />
                                    <p class="ipsp-info"><?php _e( 'Name not be used directly to build your countdown but to simplify to include it in your page.' );?></p>
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-icd-type"><?php _e( 'Type' ); ?></label>
                                <div class="ipsp-input" id="ipsp-icd-types">
                                        <?php
                                        $dpWidget = '';
                                        $dpDesign = '';
                                        $dpButton = '';
                                        $dpInfo   = '';
                                        $cdType   = $setting->getSetting( 'countdown_type', 1 );
                                        if ( $cdType == 2 ) {
                                            $dpDesign =
                                            $dpButton = ' style="display: none;"';
                                        }
                                        if ( $cdType == 1 ) {
                                            $dpInfo   = ' style="display: none;"';
                                            $dpWidget = ' style="display: none;"';
                                        }
                                        $types = array(
                                            1 => __( 'Banner' ),
                                            2 => __( 'Floating Widget' ),
                                        );
                                        foreach( $types as $key => $label ) {
                                            $checked = '';
                                            if ( $key == $cdType ) {
                                                $checked = ' checked="checked"';
                                            }
                                            echo '<label>
                                            <input' . $checked . ' type="radio" name="countdown_type" class="ipsp-icd-type" value="' . $key . '">
                                            ' . $label . '
                                            </label>';
                                        }
                                        ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section">
                        <h3><?php _e( 'Time' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-i-time-type"><?php _e( 'Expire Countdown' ); ?></label>
                                <div class="ipsp-input">
                                    <div id="ipsp-itime-type-wrap">
                                        <?php
                                        $timeType = $setting->getSetting( 'time_type', 1 );
                                        $types = array(
                                            1 => __( 'Duration Time' ),
                                            2 => __( 'Specific Date' ),
                                            3 => __( 'User Visits' ),
                                        );
                                        foreach( $types as $key => $label ) {
                                            $checked = '';
                                            if ( $key == $timeType ) {
                                                $checked = ' checked="checked"';
                                            }
                                            echo '<label>
                                            <input' . $checked . ' type="radio" name="time_type" class="ipsp-itime-type" value="' . $key . '">
                                            ' . $label . '
                                            </label>';
                                        }
                                        ?>
                                    </div>
                                    <div class="ipsp-info" id="ipsp-info-time-1">
                                        <?php _e( 'When you specify expire time as duration time, the countdown will stop after a period of time you specify' ); ?>.
                                    </div>
                                    <div class="ipsp-info" id="ipsp-info-time-2" style="display: none;">
                                        <?php _e( 'When you specify expire time as specific date the countdown will stop at the date and time you specify' ); ?>.
                                    </div>
                                    <div class="ipsp-info" id="ipsp-info-time-3" style="display: none;">
                                        <?php _e( 'When you specify expire time as user visits the countdown will stop after the number of user visits that you specify' ); ?>.
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php
                        $showDur = $showDate = $showVisit = ' style="display: none;"';
                        if ( $timeType == 1 ) {
                            $showDur = '';
                        } elseif ( $timeType == 2 ) {
                            $showDate = '';
                        } elseif ( $timeType == 3 ) {
                            $showVisit = '';
                        }
                        ?>
                        <div class="ipsp-field" id="ipsp-field-time">
                            <div id="ipsp-input-duration" class="ipsp-input-time"<?php echo $showDur; ?>>
                                <div class="ipsp-row">
                                    <label for="ipsp-i-duration"><?php _e( 'Duration' ); ?></label>
                                    <div id="ipsp-duration-inputs" class="ipsp-input clearfix">
                                        <span>
                                            <strong>Day</strong> 
                                            <input type="text" name="period_day" value="<?php echo $setting->getSetting( 'period_day', 0 ); ?>" id="ipsp-i-duration" />
                                        </span>
                                        <span>
                                            <strong>Hour</strong> 
                                            <input type="text" name="period_hour" value="<?php echo $setting->getSetting( 'period_hour', 0 ); ?>" />
                                        </span>
                                        <span>
                                            <strong>Minute</strong>
                                            <input type="text" name="period_minute" value="<?php echo $setting->getSetting( 'period_minute', 0 ); ?>" />
                                        </span>
                                        <span>
                                            <strong>Second</strong>
                                            <input type="text" name="period_second" value="<?php echo $setting->getSetting( 'period_second', 0 ); ?>" />
                                        </span>
                                    </div>
                                    <div class="ipsp-force-show">
                                        <label>
                                            <?php
                                            $checked = '';
                                            $value   = $setting->getSetting( 'force_show_dur', 1, true );
                                            if ( $value ) {
                                                $checked = ' checked="checked"';
                                            }
                                            ?>
                                            <input type="checkbox" name="force_show_dur" value="1"<?php echo $checked; ?>>
                                            <?php _e( 'Force to show empty time' ); ?>
                                        </label>
                                    </div>
                                </div>
                                <div class="ipsp-row" id="ipsp-field-time-start">
                                    <label for="ipsp-i-time-start"><?php _e( 'Start Time' ); ?></label>
                                    <div class="ipsp-input">
                                        <?php
                                        $typeSltd = $setting->getSetting( 'period_time_start', 1 );
                                        if ( $typeSltd == 1 ) {
                                            $showSp = '';
                                        } else {
                                            $showSp = ' style="display: none"';
                                        }
                                        $types = array(
                                            1 => __( 'Specific Date' ),
                                            2 => __( 'User First Visits' ),
                                        );
                                        foreach( $types as $key => $label ) {
                                            $checked = '';
                                            if ( $key == $typeSltd ) {
                                                $checked = ' checked="checked"';
                                            }
                                            echo '<label>
                                            <input' . $checked . ' type="radio" name="period_time_start" class="ipsp-i-time-start" value="' . $key . '">
                                            ' . $label . '
                                            </label>';
                                        }
                                        ?>
                                        <span class="ipsp-info"><?php _e( 'Determine the initial time of the countdown' ); ?>.</span>
                                        <div id="ipsp-start-specific"<?php echo $showSp; ?>>
                                            <?php
                                            $date      = date('Y-n-j h:i:s');
                                            $tspday    = get_date_from_gmt( $date, 'j' );
                                            $tspmonth  = get_date_from_gmt( $date, 'n' );
                                            $tspyear   = get_date_from_gmt( $date, 'Y' );
                                            $tsphour   = get_date_from_gmt( $date, 'h' );
                                            $tspminute = get_date_from_gmt( $date, 'i' );
                                            $tspsecond = get_date_from_gmt( $date, 's' );
                                            ?>
                                            <select name="startsp_day">
                                                <?php
                                                $daySltd = $setting->getSetting( 'startsp_day', $tspday );
                                                $days    = range(1,31);
                                                foreach( $days as $day ) {
                                                    $sltd = '';
                                                    if ( $daySltd == $day ) {
                                                        $sltd = ' selected="selected"';
                                                    }
                                                    echo '<option value="'.$day.'"' . $sltd . '>'.$day.'</option>';
                                                }
                                                ?>
                                            </select>
                                            <select name="startsp_month">
                                                <?php
                                                $monthSltd = $setting->getSetting( 'startsp_month', $tspmonth );
                                                $months = array(
                                                    1  => 'January',
                                                    2  => 'February',
                                                    3  => 'March',
                                                    4  => 'April',
                                                    5  => 'May',
                                                    6  => 'June',
                                                    7  => 'July',
                                                    8  => 'August',
                                                    9  => 'September',
                                                    10 => 'October',
                                                    11 => 'November',
                                                    12 => 'December',
                                                );
                                                foreach( $months as $key => $month ) {
                                                    $sltd = '';
                                                    if ( $monthSltd == $key ) {
                                                        $sltd = ' selected="selected"';
                                                    }
                                                    echo '<option value="'.$key.'"' . $sltd . '>'.__($month).'</option>';
                                                }
                                                ?>
                                            </select>
                                            <select name="startsp_year">
                                                <?php
                                                $yearSltd = $setting->getSetting( 'startsp_year', $tspyear );
                                                $years = range( date('Y'), date('Y') + 10 );
                                                foreach( $years as $year ) {
                                                    $sltd = '';
                                                    if ( $yearSltd == $year ) {
                                                        $sltd = ' selected="selected"';
                                                    }
                                                    echo '<option value="'.$year.'"' . $sltd . '>'.$year.'</option>';
                                                }
                                                ?>
                                            </select>
                                            :
                                            <span><input type="text" class="ipsp-small" name="startsp_hour" value="<?php echo $setting->getSetting( 'startsp_hour', $tsphour ); ?>" /></span>
                                            <span><input type="text" class="ipsp-small" name="startsp_minute" value="<?php echo $setting->getSetting( 'startsp_minute', $tspminute ); ?>" /></span>
                                            <span><input type="text" class="ipsp-small" name="startsp_second" value="<?php echo $setting->getSetting( 'startsp_second', $tspsecond ); ?>" /></span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div id="ipsp-input-specific" class="ipsp-input-time"<?php echo $showDate; ?>>
                                <div class="ipsp-row">
                                    <label for="ipsp-i-date"><?php _e( 'Date' ); ?></label>
                                    <div class="ipsp-input">
                                        <select name="specific_day" id="ipsp-i-date">
                                            <?php
                                            $daySltd = $setting->getSetting( 'specific_day' );
                                            $days    = range(1,31);
                                            foreach( $days as $day ) {
                                                $sltd = '';
                                                if ( $daySltd == $day ) {
                                                    $sltd = ' selected="selected"';
                                                }
                                                echo '<option value="'.$day.'"' . $sltd . '>'.$day.'</option>';
                                            }
                                            ?>
                                        </select>
                                        <select name="specific_month">
                                            <?php
                                            $monthSltd = $setting->getSetting( 'specific_month' );
                                            $months = array(
                                                1  => 'January',
                                                2  => 'February',
                                                3  => 'March',
                                                4  => 'April',
                                                5  => 'May',
                                                6  => 'June',
                                                7  => 'July',
                                                8  => 'August',
                                                9  => 'September',
                                                10 => 'October',
                                                11 => 'November',
                                                12 => 'December',
                                            );
                                            foreach( $months as $key => $month ) {
                                                $sltd = '';
                                                if ( $monthSltd == $key ) {
                                                    $sltd = ' selected="selected"';
                                                }
                                                echo '<option value="'.$key.'"' . $sltd . '>'.__($month).'</option>';
                                            }
                                            ?>
                                        </select>
                                        <select name="specific_year">
                                            <?php
                                            $yearSltd = $setting->getSetting( 'specific_year' );
                                            $years = range( date('Y'), date('Y') + 10 );
                                            foreach( $years as $year ) {
                                                $sltd = '';
                                                if ( $yearSltd == $year ) {
                                                    $sltd = ' selected="selected"';
                                                }
                                                echo '<option value="'.$year.'"' . $sltd . '>'.$year.'</option>';
                                            }
                                            ?>
                                        </select>
                                        :
                                        <span><input type="text" class="ipsp-small" name="specific_hour" value="<?php echo $setting->getSetting( 'specific_hour', '00' ); ?>" /></span>
                                        <span><input type="text" class="ipsp-small" name="specific_minute" value="<?php echo $setting->getSetting( 'specific_minute', '00' ); ?>" /></span>
                                        <span><input type="text" class="ipsp-small" name="specific_second" value="<?php echo $setting->getSetting( 'specific_second', '00' ); ?>" /></span>
                                    </div>
                                    <div class="ipsp-force-show">
                                        <label>
                                            <?php
                                            $checked = '';
                                            $value   = $setting->getSetting( 'force_show_sp', 1, true );
                                            if ( $value ) {
                                                $checked = ' checked="checked"';
                                            }
                                            ?>
                                            <input type="checkbox" name="force_show_sp" value="1"<?php echo $checked; ?>>
                                            <?php _e( 'Force to show empty time' ); ?>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div id="ipsp-input-visit" class="ipsp-input-time"<?php echo $showVisit; ?>>
                                <div class="ipsp-row">
                                    <label for="ipsp-i-time-visit"><?php _e( 'Maximum number of visits' ); ?></label>
                                    <div class="ipsp-input">
                                        <input type="text" name="visit_number" id="ipsp-i-time-visit" value="<?php echo $setting->getSetting( 'visit_number' ); ?>" />
                                    </div>
                                </div>
                                <div class="ipsp-row">
                                    <label for="ipsp-i-visit-text"><?php _e( 'Description of the rest of the visit' ); ?></label>
                                    <div class="ipsp-input">
                                        <input type="text" name="visit_text" id="ipsp-i-visit-text" value="<?php echo $setting->getSetting( 'visit_text', 'Remaining {visit_number} visits' ); ?>" />
                                        <span class="info">Text {visit_number} will be replaced with the number of remaining visits</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section">
                        <h3><?php _e( 'Action After Expiration' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-input-action"><?php _e( 'Redirect URL' ); ?></label>
                                <div class="ipsp-input">
                                    <input type="text" id="ipsp-input-action" name="action_url" value="<?php echo $setting->getSetting( 'action_url' ); ?>" />
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section">
                        <h3><?php _e( 'Banner Editor' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-input-content"><?php _e( 'Content' ); ?></label>
                                <div class="ipsp-input">
                                    <div class="ipsp-input-content">
                                        <h4><?php _e( 'Text to Display Before Countdown Timer Hits Zero' ); ?> <span class="ipsp-ic">[-]</span></h4>
                                        <div class="ipsp-content-editor">
                                            <p class="ipsp-content-limit"<?php echo $dpInfo; ?>><strong>Note: <?php _e( 'Maximum character is' ); ?> 20</strong></p>
                                            <?php 
                                            $content = $setting->getSetting( 'initial-content', '<strong><span style="color: #3366ff;">Click Here To Get The Special Price</span></strong>', true );
                                            wp_editor( $content, 'initial-content', array( 'editor_height' => 50 ) ); 
                                            ?>
                                        </div>
                                    </div>
                                    <div class="ipsp-input-content">
                                        <h4><?php _e( 'Text to Display after a Specified Date and Time (Tips - Optional: You can use this to warn visitors to act fast hours/minutes before Countdown Timer Hits Zero)' ); ?> <span class="ipsp-ic">[+]</span></h4>
                                        <div class="ipsp-content-editor" style="display: none;">
                                            <div class="ipsp-warning-time">
                                                <?php
                                                $showDur = $showDate = $showVisit = ' style="display: none;"';
                                                if ( $timeType == 1 ) {
                                                    $showDur = '';
                                                } elseif ( $timeType == 2 ) {
                                                    $showDate = '';
                                                } elseif ( $timeType == 3 ) {
                                                    $showVisit = '';
                                                }
                                                ?>
                                                <div class="ipsp-wt ipsp-wt-duration" <?php echo $showDur; ?>>
                                                    <?php _e( 'Content appearing on' ); ?> :
                                                    <span>
                                                        <strong>Day</strong>: 
                                                        <input type="text" name="wt1_duration_day" value="<?php echo $setting->getSetting( 'wt1_duration_day' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Hour</strong>: 
                                                        <input type="text" name="wt1_duration_hour" value="<?php echo $setting->getSetting( 'wt1_duration_hour' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Minute</strong>: 
                                                        <input type="text" name="wt1_duration_minute" value="<?php echo $setting->getSetting( 'wt1_duration_minute' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Second</strong>: 
                                                        <input type="text" name="wt1_duration_second" value="<?php echo $setting->getSetting( 'wt1_duration_second' ); ?>" />
                                                    </span>
                                                </div>
                                                <div class="ipsp-wt ipsp-wt-date" <?php echo $showDate; ?>>
                                                    <?php _e( 'Content appearing on' ); ?> :
                                                    <select name="wt1_date_day">
                                                        <?php
                                                        $daySltd = $setting->getSetting( 'wt1_date_day' );
                                                        $days    = range(1,31);
                                                        foreach( $days as $day ) {
                                                            $sltd = '';
                                                            if ( $daySltd == $day ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$day.'"' . $sltd . '>'.$day.'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    <select name="wt1_date_month">
                                                        <?php
                                                        $monthSltd = $setting->getSetting( 'wt1_date_month' );
                                                        $months = array(
                                                            1  => 'January',
                                                            2  => 'February',
                                                            3  => 'March',
                                                            4  => 'April',
                                                            5  => 'May',
                                                            6  => 'June',
                                                            7  => 'July',
                                                            8  => 'August',
                                                            9  => 'September',
                                                            10 => 'October',
                                                            11 => 'November',
                                                            12 => 'December',
                                                        );
                                                        foreach( $months as $key => $month ) {
                                                            $sltd = '';
                                                            if ( $monthSltd == $key ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$key.'"' . $sltd . '>'.__($month).'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    <select name="wt1_date_year">
                                                        <?php
                                                        $yearSltd = $setting->getSetting( 'wt1_date_year' );
                                                        $years = range( date('Y'), date('Y') + 10 );
                                                        foreach( $years as $year ) {
                                                            $sltd = '';
                                                            if ( $yearSltd == $year ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$year.'"' . $sltd . '>'.$year.'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    :
                                                    <span><input type="text" class="ipsp-small" name="wt1_date_hour" value="<?php echo $setting->getSetting( 'wt1_date_hour' ); ?>" /></span>
                                                    <span><input type="text" class="ipsp-small" name="wt1_date_minute" value="<?php echo $setting->getSetting( 'wt1_date_minute' ); ?>" /></span>
                                                    <span><input type="text" class="ipsp-small" name="wt1_date_second" value="<?php echo $setting->getSetting( 'wt1_date_second' ); ?>" /></span>
                                                </div>
                                                <div class="ipsp-wt ipsp-wt-visit" <?php echo $showVisit; ?>>
                                                    <?php _e( 'Content appearing after' ); ?> :
                                                    <input type="text" name="wt1_visit" value="<?php echo $setting->getSetting( 'wt1_visit' ); ?>" class="ipsp-small" /> visits
                                                </div>
                                            </div>
                                            <p class="ipsp-content-limit"<?php echo $dpInfo; ?>><strong>Note: <?php _e( 'Maximum character is' ); ?> 20</strong></p>
                                            <?php 
                                            $content = $setting->getSetting( 'warning-content-1', '<strong>Better Hurry, This Special Price is Expired Soon!</strong>', true );
                                            wp_editor( $content, 'warning-content-1', array( 'editor_height' => 50 ) ); 
                                            ?>
                                        </div>
                                    </div>
                                    <div class="ipsp-input-content">
                                        <h4><?php _e( 'Text to Display after a Specified Date and Time (Text to Display Upon Expiry )' ); ?> <span class="ipsp-ic">[+]</span></h4>
                                        <div class="ipsp-content-editor" style="display: none;">
                                            <div class="ipsp-warning-time">
                                                <div class="ipsp-wt ipsp-wt-duration" <?php echo $showDur; ?>>
                                                    <?php _e( 'Content appearing on' ); ?> :
                                                    <span>
                                                        <strong>Day</strong>: 
                                                        <input type="text" name="wt2_duration_day" value="<?php echo $setting->getSetting( 'wt2_duration_day' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Hour</strong>: 
                                                        <input type="text" name="wt2_duration_hour" value="<?php echo $setting->getSetting( 'wt2_duration_hour' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Minute</strong>: 
                                                        <input type="text" name="wt2_duration_minute" value="<?php echo $setting->getSetting( 'wt2_duration_minute' ); ?>" />
                                                    </span>
                                                    <span>
                                                        <strong>Second</strong>: 
                                                        <input type="text" name="wt2_duration_second" value="<?php echo $setting->getSetting( 'wt2_duration_second' ); ?>" />
                                                    </span>
                                                </div>
                                                <div class="ipsp-wt ipsp-wt-date" <?php echo $showDate; ?>>
                                                    <?php _e( 'Content appearing on' ); ?> :
                                                    <select name="wt2_date_day">
                                                        <?php
                                                        $daySltd = $setting->getSetting( 'wt2_date_day' );
                                                        $days    = range(1,31);
                                                        foreach( $days as $day ) {
                                                            $sltd = '';
                                                            if ( $daySltd == $day ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$day.'"' . $sltd . '>'.$day.'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    <select name="wt2_date_month">
                                                        <?php
                                                        $monthSltd = $setting->getSetting( 'wt2_date_month' );
                                                        $months = array(
                                                            1  => 'January',
                                                            2  => 'February',
                                                            3  => 'March',
                                                            4  => 'April',
                                                            5  => 'May',
                                                            6  => 'June',
                                                            7  => 'July',
                                                            8  => 'August',
                                                            9  => 'September',
                                                            10 => 'October',
                                                            11 => 'November',
                                                            12 => 'December',
                                                        );
                                                        foreach( $months as $key => $month ) {
                                                            $sltd = '';
                                                            if ( $monthSltd == $key ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$key.'"' . $sltd . '>'.__($month).'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    <select name="wt2_date_year">
                                                        <?php
                                                        $yearSltd = $setting->getSetting( 'wt2_date_year' );
                                                        $years = range( date('Y'), date('Y') + 10 );
                                                        foreach( $years as $year ) {
                                                            $sltd = '';
                                                            if ( $yearSltd == $year ) {
                                                                $sltd = ' selected="selected"';
                                                            }
                                                            echo '<option value="'.$year.'"' . $sltd . '>'.$year.'</option>';
                                                        }
                                                        ?>
                                                    </select>
                                                    :
                                                    <span><input type="text" class="ipsp-small" name="wt2_date_hour" value="<?php echo $setting->getSetting( 'wt2_date_hour' ); ?>" /></span>
                                                    <span><input type="text" class="ipsp-small" name="wt2_date_minute" value="<?php echo $setting->getSetting( 'wt2_date_minute' ); ?>" /></span>
                                                    <span><input type="text" class="ipsp-small" name="wt2_date_second" value="<?php echo $setting->getSetting( 'wt2_date_second' ); ?>" /></span>
                                                </div>
                                                <div class="ipsp-wt ipsp-wt-visit" <?php echo $showVisit; ?>>
                                                    <?php _e( 'Content appearing after' ); ?> :
                                                    <input type="text" class="ipsp-small" name="wt2_visit" value="<?php echo $setting->getSetting( 'wt2_visit' ); ?>" /> visits
                                                </div>
                                            </div>
                                            <p class="ipsp-content-limit"<?php echo $dpInfo; ?>><strong>Note: <?php _e( 'Maximum character is' ); ?> 20</strong></p>
                                            <?php
                                            $content = $setting->getSetting( 'warning-content-2', '<strong>This Offer Has Now Expired!</strong>', true );
                                            wp_editor( $content, 'warning-content-2', array( 'editor_height' => 50 ) ); 
                                            ?>
                                        </div>
                                    </div>
                                    
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section" id="ipsp-section-design"<?php echo $dpDesign; ?>>
                        <h3><?php _e( 'Banner Design' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-input-style"><?php _e( 'Style' ); ?></label>
                                <div class="ipsp-input">
                                    <?php $this->inputStyle( $setting ); ?>
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-input-bgcolor"><?php _e( 'Background Color' ); ?></label>
                                <div class="ipsp-input">
                                    <?php
                                    $bgcolor = $setting->getSetting( 'design_bgcolor', '#ffffff' );
                                    ?>
                                    <input type="text" class="color-picker" name="design_bgcolor" id="ipsp-input-bgcolor" value="<?php echo $bgcolor; ?>" />
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-input-color"><?php _e( 'Font Color' ); ?></label>
                                <div class="ipsp-input">
                                    <?php
                                    $color = $setting->getSetting( 'design_color', '#000000' );
                                    ?>
                                    <input type="text" class="color-picker" name="design_color" id="ipsp-input-color" value="<?php echo $color; ?>" />
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-input-font"><?php _e( 'Font' ); ?></label>
                                <div class="ipsp-input">
                                    <?php $this->inputFont( $setting ); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section" id="ipsp-widget-design"<?php echo $dpWidget; ?>>
                        <h3><?php _e( 'Widget Design' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                <label for="ipsp-input-font"><?php _e( 'Font' ); ?></label>
                                <div class="ipsp-input">
                                    <?php $this->inputFont( $setting, 'widget_font' ); ?>
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-input-color"><?php _e( 'Font Color' ); ?></label>
                                <div class="ipsp-input">
                                    <?php
                                    $color = $setting->getSetting( 'widget_color', '#333333' );
                                    ?>
                                    <input type="text" class="color-picker" name="widget_color" id="ipsp-input-wcolor" value="<?php echo $color; ?>" />
                                </div>
                            </div>
                            <div class="ipsp-row">
                                <label for="ipsp-input-bgcolor"><?php _e( 'Top Background Color' ); ?></label>
                                <div class="ipsp-input">
                                    <?php
                                    $bgcolor = $setting->getSetting( 'widget_bgcolor', '#727272' );
                                    ?>
                                    <input type="text" class="color-picker" name="widget_bgcolor" id="ipsp-input-wbgcolor" value="<?php echo $bgcolor; ?>" />
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-section" id="ipsp-section-button"<?php echo $dpButton; ?>>
                        <h3><?php _e( 'Call To Action Button' ); ?></h3>
                        <div class="ipsp-field">
                            <div class="ipsp-row">
                                    <label class="ipsp-normal">
                                        <?php
                                        $checked    = '';
                                        $buttonShow = ' style="display: none;"';
                                        if ( $setting->getSetting( 'use_button' ) ) {
                                            $checked    = ' checked="checked"';
                                            $buttonShow = '';
                                        }
                                        ?>
                                        <input type="checkbox" id="ipsp-use-button" name="use_button" value="1"<?php echo $checked; ?> /> 
                                        <?php _e( 'Add call to action button to your banner countdown' ); ?>.
                                    </label>
                            </div>
                            <div id="ipsp-button-options"<?php echo $buttonShow; ?>>
                                <div class="ipsp-row">
                                    <label for="ipsp-input-button-bgcolor"><?php _e( 'Button Design' ); ?></label>
                                    <div class="ipsp-input">
                                        <div class="ipsp-design-select">
                                            <?php
                                            $plgurl  = plugin_dir_url( dirname(__FILE__) );
                                            $ui      = $plgurl . 'img/button/';
                                            $design  = $setting->getSetting( 'button_design' );
                                            $designs = array(
                                                'warning-buy-until-ins',
                                                'warning-buy-limit-ins',
                                                'warning-get-until-ins',
                                                'warning-get-limit-ins',
                                                'warning-buy-until',
                                                'warning-buy-limit',
                                                'warning-get-until',
                                                'warning-get-limit',
                                                'danger-buy-until-ins',
                                                'danger-buy-limit-ins',
                                                'danger-get-until-ins',
                                                'danger-get-limit-ins',
                                                'danger-buy-until',
                                                'danger-buy-limit',
                                                'danger-get-until',
                                                'danger-get-limit',
                                                'success-buy-until-ins',
                                                'success-buy-limit-ins',
                                                'success-get-until-ins',
                                                'success-get-limit-ins',
                                                'success-buy-until',
                                                'success-buy-limit',
                                                'success-get-until',
                                                'success-get-limit',
                                                'info-buy-until-ins',
                                                'info-buy-limit-ins',
                                                'info-get-until-ins',
                                                'info-get-limit-ins',
                                                'info-buy-until',
                                                'info-buy-limit',
                                                'info-get-until',
                                                'info-get-limit',
                                                'info-buy-until-ins',
                                                'clean-buy-limit-ins',
                                                'clean-get-until-ins',
                                                'clean-get-limit-ins',
                                                'clean-buy-until',
                                                'clean-buy-limit',
                                                'clean-get-until',
                                                'clean-get-limit',
                                                'dark-buy-until-ins',
                                                'dark-buy-limit-ins',
                                                'dark-get-until-ins',
                                                'dark-get-limit-ins',
                                                'dark-buy-until',
                                                'dark-buy-limit',
                                                'dark-get-until',
                                                'dark-get-limit',
                                            );
                                            echo '<ul class="clearfix">';
                                            foreach( $designs as $slug ) {
                                                $checked = '';
                                                if ( $slug == $design ) {
                                                    $checked = ' checked="checked"';
                                                }
                                                echo '<li>
                                                        <label>
                                                            <input' . $checked . ' type="radio" name="button_design" value="' . $slug . '">
                                                            <img src="' . $ui . 'small-' . $slug . '.png" alt="" />
                                                        </label>
                                                     </li>';
                                            }
                                            echo '</ul>';
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="ipsp-row">
                                    <label for="ipsp-input-button-link"><?php _e( 'Link' ); ?></label>
                                    <div class="ipsp-input">
                                        <input type="text" id="ipsp-input-button-link" name="button_link" value="<?php echo $setting->getSetting( 'button_link' ); ?>" />
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="ipsp-button">
                        <?php
                        if ( $countdown ) {
                            $btnid = 'ipsp_save_setting';
                            $label = __( 'Save' );
                        } else {
                            $btnid = 'ipsp_add_countdown';
                            $label = __( 'Add' );
                        }
                        ?>
                        <input type="submit" id="<?php echo $btnid; ?>" class="button button-large button-primary" name="ipsp_save_setting" value="<?php echo $label; ?>" />
                    </div>
                
                </form>
                </div>
            </div>
        <?php
        }
        
        /**
         * Input style
         */
        public function inputStyle( $setting = false )
        {
            $plgurl = plugin_dir_url( dirname(__FILE__) );
            $prvurl = $plgurl . 'img/preview/';
            $styles = array(
                'style1' => 'Style 1',
                'style2' => 'Style 2',
                'style3' => 'Style 3',
                'style4' => 'Style 4',
                'style5' => 'Style 5',
            );
            $selectedLabel = 'Style 1';
            $selectedValue = 'style1';
            if ( $setting ) {
                $style = $setting->getSetting( 'design_style', 'style1' );
                $selectedValue = $style;
                if ( ! empty( $styles[$style] )) {
                    $selectedLabel = $styles[$style];
                } else {
                    $selectedLabel = 'Unknown';
                }
            }
        ?>
            <div class="ipsp-menu ipsp-gen-menu ipsp-style-menu">
                <div class="ipsp-selected">
                    <div class="ipsp-selected-box">
                        <?php echo $selectedLabel; ?>
                    </div>
                    <span class="toggle"></span>
                </div>
                <div class="ipsp-select" style="display: none;">
                    <div class="ipsp-select-content">
                        <ul class="clearfix">
                            <?php
                            foreach( $styles as $id => $label ) :
                                $src = $prvurl . $id . '.jpg';
                            ?>
                                <li data-select="<?php echo $id; ?>">
                                    <strong class="ipsp-select-label"><?php echo $label; ?></strong>
                                    <img src="<?php echo $src; ?>" alt="<?php echo $label; ?>">
                                </li>
                            <?php
                            endforeach;
                            ?>
                        </ul>
                    </div>
                </div>
                <input type="hidden" name="design_style" class="ipsp-input-select" id="ipsp-input-style" value="<?php echo $selectedValue; ?>" />
            </div>
        <?php
        }
        
        /**
         * Option font
         */
        public function inputFont( $setting = false, $name = 'design_font' )
        {
            $fonts = array(
                'Arial'             => 'Arial',
                'Arial_Black'       => 'Arial Black',
                'Cooper_Black'      => 'Cooper Black',
                'Garamond'          => 'Garamond',
                'Georgia'           => 'Georgia',
                'Impact'            => 'Impact',
                'Tahoma'            => 'Tahoma',
                'Times_New_Roman'   => 'Times New Roman',
                'Trebuchet_MS'      => 'Trebuchet MS',
                'Verdana'           => 'Verdana',
            );
            $selectedLabel = 'Arial';
            $selectedValue = 'Arial';
            if ( $setting ) {
                $font = $setting->getSetting( $name, 'Arial' );
                $selectedValue = $font;
                if ( ! empty( $fonts[$font] )) {
                    $selectedLabel = $fonts[$font];
                } else {
                    $selectedLabel = 'Unknown';
                }
            }
        ?>
                <div class="ipsp-menu ipsp-gen-menu ipsp-font-menu">
                    <div class="ipsp-selected">
                        <div class="ipsp-selected-box">
                            <?php echo $selectedLabel; ?>
                        </div>
                        <span class="toggle"></span>
                    </div>
                    <div class="ipsp-select" style="display: none;">
                        <div class="ipsp-select-content">
                            <ul class="clearfix">
                                <?php
                                foreach( $fonts as $id => $label ) :
                                ?>
                                    <li data-select="<?php echo $id; ?>">
                                        <strong class="ipsp-select-label"><?php echo $label; ?></strong>
                                    </li>
                                <?php
                                endforeach;
                                ?>
                            </ul>
                        </div>
                    </div>
                    <input type="hidden" name="<?php echo $name; ?>" class="ipsp-input-select" id="ipsp-input-ffamily" value="<?php echo $selectedValue; ?>" />
                </div>
        <?php
        }
    }
}
?>