<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPScarcityPlus_Ajax' )) {

    class IPScarcityPlus_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            
            'ipsp_preview'  => 'getPreview',
            'ipsp_save'     => 'save',
            'ipsp_delete'   => 'delete',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipsp'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Mendapatkan konten preview
         *
         * @return void
         */
        public function getPreview()
        {
            $id = $this->_saveSetting();
            $result['id'] = $id;
            if ( $id ) {
                $result['status'] = 1;
            } else {
                $result['status'] = 0;
            }
            
            $ipsp_factory = new IPScarcityPlus_Factory($id,true);
            $result['preview'] = $ipsp_factory->create(true);
            
            echo json_encode( $result );
            die();
        }
        
        /**
         * Menyimpan data pengaturan
         *
         * @return void
         */
        public function save()
        {
            $id = $this->_saveSetting();
            $result['id'] = $id;
            if ( $id ) {
                $result['status'] = 1;
            } else {
                $result['status'] = 0;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Menyimpan data pengaturan
         *
         * @return int
         */
        protected function _saveSetting()
        {
            $data   = $this->_getDataSetting();
            if ( ! empty( $_POST['countdown_id'] )) {
                $id = absint( $_POST['countdown_id'] );
                $this->_edit( $id );
            } else {
                $id = $this->_add();
            }
            if ( ! empty( $id )) {
                $setting = new IPScarcityPlus_Setting( $id );
                $setting->setSettings( $data );
            }
            return $id;
        }
        
        /**
         * Edit countdown
         *
         * @param  int   $id
         * @return int
         */
        protected function _edit( $id )
        {
            $result = 0;
            if ( $countdown = get_post( $id )) {
                if ( ! empty( $_POST['countdown_name'] ) && $_POST['countdown_name'] != $countdown->post_title ) {
                    $data['post_title'] = apply_filters( 'single_post_title', $_POST['countdown_name'] );
                }
                if ( ! empty( $data )) {
                    $data['ID'] = $countdown->ID;
                    $result = wp_update_post( $data );
                }
            }
            return $result;
        }
        
        /**
         * Add countdown
         *
         * @return int
         */
        protected function _add()
        {
            global $user_ID;
            if ( empty( $_POST['countdown_name'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['countdown_name'] );
            }
            $dataPost = array(
                'post_status' => 1,
                'post_type'   => 'ipcountdown', 
                'post_author' => $user_ID,
                'post_title'  => $title
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Mendapatkan data pengaturan
         *
         * @return array
         */
        protected function _getDataSetting()
        {
            $data  = array();
            
            if ( isset( $_POST['countdown_type'] )) {
                $data['countdown_type'] = absint( $_POST['countdown_type'] );
            }
            /**
             * Setting duration time
             **/
            $ttype = 1;
            if ( ! empty( $_POST['time_type'] )) {
                $ttype             = 
                $data['time_type'] = absint( $_POST['time_type'] );
            }
            if ( $ttype == 1 ) {
                if ( isset( $_POST['period_day'] )) {
                    $data['period_day'] = absint( $_POST['period_day'] );
                }
                if ( isset( $_POST['period_hour'] )) {
                    $data['period_hour'] = absint( $_POST['period_hour'] );
                }
                if ( isset( $_POST['period_minute'] )) {
                    $data['period_minute'] = absint( $_POST['period_minute'] );
                }
                if ( isset( $_POST['period_second'] )) {
                    $data['period_second'] = absint( $_POST['period_second'] );
                }
                if ( isset( $_POST['force_show_dur'] )) {
                    $data['force_show_dur'] = 1;
                } else {
                    $data['force_show_dur'] = 0;
                }
                $tstart = 1;
                if ( isset( $_POST['period_time_start'] )) {
                    $tstart = $data['period_time_start'] = absint( $_POST['period_time_start'] );
                }
                if ( $tstart == 1 ) {
                    if ( ! empty( $_POST['startsp_day'] )) {
                        $data['startsp_day'] = absint( $_POST['startsp_day'] );
                    }
                    if ( ! empty( $_POST['startsp_month'] )) {
                        $data['startsp_month'] = absint( $_POST['startsp_month'] );
                    }
                    if ( ! empty( $_POST['startsp_year'] )) {
                        $data['startsp_year'] = absint( $_POST['startsp_year'] );
                    }
                    if ( isset( $_POST['startsp_hour'] )) {
                        $data['startsp_hour'] = absint( $_POST['startsp_hour'] );
                    }
                    if ( isset( $_POST['startsp_minute'] )) {
                        $data['startsp_minute'] = absint( $_POST['startsp_minute'] );
                    }
                    if ( isset( $_POST['startsp_second'] )) {
                        $data['startsp_second'] = absint( $_POST['startsp_second'] );
                    }
                }
            }
            elseif ( $ttype == 2 ) {
                if ( ! empty( $_POST['specific_day'] )) {
                    $data['specific_day'] = absint( $_POST['specific_day'] );
                }
                if ( ! empty( $_POST['specific_month'] )) {
                    $data['specific_month'] = absint( $_POST['specific_month'] );
                }
                if ( ! empty( $_POST['specific_year'] )) {
                    $data['specific_year'] = absint( $_POST['specific_year'] );
                }
                if ( isset( $_POST['specific_hour'] )) {
                    $data['specific_hour'] = absint( $_POST['specific_hour'] );
                }
                if ( isset( $_POST['specific_minute'] )) {
                    $data['specific_minute'] = absint( $_POST['specific_minute'] );
                }
                if ( isset( $_POST['specific_second'] )) {
                    $data['specific_second'] = absint( $_POST['specific_second'] );
                }
                if ( isset( $_POST['force_show_sp'] )) {
                    $data['force_show_sp'] = 1;
                } else {
                    $data['force_show_sp'] = 0;
                }
            }
            elseif ( $ttype == 3 ) {
                if ( ! empty( $_POST['visit_number'] )) {
                    $data['visit_number'] = absint( $_POST['visit_number'] );
                }
                if ( ! empty( $_POST['visit_text'] )) {
                    $data['visit_text'] = apply_filters( 'pre_term_description', $_POST['visit_text'] );
                }
            }
            
            /**
             * Expired Action
             **/
            if ( isset( $_POST['action_url'] )) {
                $data['action_url'] = apply_filters( 'pre_link_url', $_POST['action_url'] );
            }
            if ( isset( $_POST['use_confirm'] ) && ! empty( $_POST['use_confirm'] )) {
                $data['use_confirm'] = 1;
                if ( ! empty( $_POST['confirm_info'] )) {
                    $data['confirm_info'] = apply_filters( 'pre_term_description', $_POST['confirm_info'] );
                }
                if ( ! empty( $_POST['confirm_button'] )) {
                    $data['confirm_button'] = apply_filters( 'pre_term_description', $_POST['confirm_button'] );
                }
            
            } else {
                $data['use_confirm']    = 0;
                $data['confirm_title']  = '';
                $data['confirm_info']   = '';
                $data['confirm_button'] = '';
            }
            
            /**
             * Content
             **/
            if ( isset( $_POST['initial-content'] )) {
                $data['initial-content'] = $_POST['initial-content'];
            }
            /** Warning content 1 **/
            if ( isset( $_POST['warning-content-1'] )) {
                $data['warning-content-1'] = $_POST['warning-content-1'];
            }
            if ( $ttype == 1 ) {
                if ( isset( $_POST['wt1_duration_day'] )) {
                    $data['wt1_duration_day'] = absint( $_POST['wt1_duration_day'] );
                }
                if ( isset( $_POST['wt1_duration_hour'] )) {
                    $data['wt1_duration_hour'] = absint( $_POST['wt1_duration_hour'] );
                }
                if ( isset( $_POST['wt1_duration_minute'] )) {
                    $data['wt1_duration_minute'] = absint( $_POST['wt1_duration_minute'] );
                }
                if ( isset( $_POST['wt1_duration_second'] )) {
                    $data['wt1_duration_second'] = absint( $_POST['wt1_duration_second'] );
                }
            }
            elseif ( $ttype == 2 ) {
                if ( ! empty( $_POST['wt1_date_day'] )) {
                    $data['wt1_date_day'] = absint( $_POST['wt1_date_day'] );
                }
                if ( ! empty( $_POST['wt1_date_month'] )) {
                    $data['wt1_date_month'] = absint( $_POST['wt1_date_month'] );
                }
                if ( ! empty( $_POST['wt1_date_year'] )) {
                    $data['wt1_date_year'] = absint( $_POST['wt1_date_year'] );
                }
                if ( isset( $_POST['wt1_date_hour'] )) {
                    $data['wt1_date_hour'] = absint( $_POST['wt1_date_hour'] );
                }
                if ( isset( $_POST['wt1_date_minute'] )) {
                    $data['wt1_date_minute'] = absint( $_POST['wt1_date_minute'] );
                }
                if ( isset( $_POST['wt1_date_second'] )) {
                    $data['wt1_date_second'] = absint( $_POST['wt1_date_second'] );
                }
            }
            elseif ( $ttype == 3 ) {
                if ( ! empty( $_POST['wt1_visit'] )) {
                    $data['wt1_visit'] = absint( $_POST['wt1_visit'] );
                }
            }
            
            /** Warning content 2 **/
            if ( isset( $_POST['warning-content-2'] )) {
                $data['warning-content-2'] = $_POST['warning-content-2'];
            }
            if ( $ttype == 1 ) {
                if ( isset( $_POST['wt2_duration_day'] )) {
                    $data['wt2_duration_day'] = absint( $_POST['wt2_duration_day'] );
                }
                if ( isset( $_POST['wt2_duration_hour'] )) {
                    $data['wt2_duration_hour'] = absint( $_POST['wt2_duration_hour'] );
                }
                if ( isset( $_POST['wt2_duration_minute'] )) {
                    $data['wt2_duration_minute'] = absint( $_POST['wt2_duration_minute'] );
                }
                if ( isset( $_POST['wt2_duration_second'] )) {
                    $data['wt2_duration_second'] = absint( $_POST['wt2_duration_second'] );
                }
            }
            elseif ( $ttype == 2 ) {
                if ( ! empty( $_POST['wt2_date_day'] )) {
                    $data['wt2_date_day'] = absint( $_POST['wt2_date_day'] );
                }
                if ( ! empty( $_POST['wt2_date_month'] )) {
                    $data['wt2_date_month'] = absint( $_POST['wt2_date_month'] );
                }
                if ( ! empty( $_POST['wt2_date_year'] )) {
                    $data['wt2_date_year'] = absint( $_POST['wt2_date_year'] );
                }
                if ( isset( $_POST['wt2_date_hour'] )) {
                    $data['wt2_date_hour'] = absint( $_POST['wt2_date_hour'] );
                }
                if ( isset( $_POST['wt2_date_minute'] )) {
                    $data['wt2_date_minute'] = absint( $_POST['wt2_date_minute'] );
                }
                if ( isset( $_POST['wt2_date_second'] )) {
                    $data['wt2_date_second'] = absint( $_POST['wt2_date_second'] );
                }
            }
            elseif ( $ttype == 3 ) {
                if ( ! empty( $_POST['wt2_visit'] )) {
                    $data['wt2_visit'] = absint( $_POST['wt2_visit'] );
                }
            }
            
            /**
             * Design
             **/
            if ( ! empty( $_POST['design_style'] )) {
                $data['design_style'] = apply_filters( 'single_post_title', $_POST['design_style'] );
            }
            if ( isset( $_POST['design_bgcolor'] )) {
                $data['design_bgcolor'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['design_bgcolor'] );
            }
            if ( isset( $_POST['design_color'] )) {
                $data['design_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['design_color'] );
            }
            if ( ! empty( $_POST['design_font'] )) {
                $data['design_font'] = apply_filters( 'single_post_title', $_POST['design_font'] );
            }
            
            /**
             * Widget Design
             **/
            if ( isset( $_POST['widget_bgcolor'] )) {
                $data['widget_bgcolor'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['widget_bgcolor'] );
            }
            if ( isset( $_POST['widget_color'] )) {
                $data['widget_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['widget_color'] );
            }
            if ( ! empty( $_POST['widget_font'] )) {
                $data['widget_font'] = apply_filters( 'single_post_title', $_POST['widget_font'] );
            }
            
            /**
             * Button
             **/
            if ( isset( $_POST['use_button'] ) && ! empty( $_POST['use_button'] )) {
                $data['use_button'] = 1;
                if ( isset( $_POST['button_bgcolor'] )) {
                    $data['button_bgcolor'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['button_bgcolor'] );
                }
                if ( isset( $_POST['button_color'] )) {
                    $data['button_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['button_color'] );
                }
                if ( isset( $_POST['button_label'] )) {
                    $data['button_label'] = apply_filters( 'single_post_title', $_POST['button_label'] );
                }
                if ( isset( $_POST['button_link'] )) {
                    $data['button_link'] = apply_filters( 'pre_link_url', $_POST['button_link'] );
                }
                if ( isset( $_POST['button_design'] )) {
                    $data['button_design'] = apply_filters( 'pre_term_description', $_POST['button_design'] );
                }
            
            } else {
                $data['use_button']      = 0;
                $data['button_bgcolor']  = '';
                $data['button_color']    = '';
                $data['button_label']    = '';
                $data['button_link']     = '';
            }
            
            return $data;
        }
        
        /**
         * Processing ajax for delete countdown
         *
         * @return void
         */
        public function delete()
        {
            $countdown = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id     = absint( $_REQUEST['id'] );
                $countdown = get_post( $id );
            }
            if ( ! $countdown ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            $result = wp_delete_post( $countdown->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'data'    => array(
                        'message'  => __( 'Successfully remove the countdown' )
                    )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Failed to remove the countdown' )
                    )
                ) );
            }
            die();
        }
    }
    
}
?>