<?php
/**
 * Class for build count down
 */
if ( ! class_exists( 'IPScarcityPlus_Factory' )) {

    class IPScarcityPlus_Factory
    {
        /**
         * Take data countdown
         *
         * @var object
         */
        protected $_countdown;
        
        /**
         * Take data countdown setting
         *
         * @var object
         */
        protected $_setting;
        
        /**
         * Take position of countdown
         *
         * @var int
         */
        protected $_position;
        
        /**
         * Take duration of counter
         *
         * @var int
         */
        protected $_duration;
        
        /**
         * Take start of counter
         *
         * @var int
         */
        protected $_startTime;
        
        /**
         * Take start of counter
         *
         * @var int
         */
        protected $_startCounter;
        
        /**
         * Take first warning time
         *
         * @var int
         */
        protected $_warning1Time;
        
        /**
         * Take second warning time
         *
         * @var int
         */
        protected $_warning2Time;
        
        /**
         * Take first warning time
         *
         * @var int
         */
        protected $_warning1;
        
        /**
         * Take second warning time
         *
         * @var int
         */
        protected $_warning2;
        
        /**
         * Take visit left
         *
         * @var int
         */
        protected $_visitLeft;
        
        /**
         * Is for preview
         *
         * @var boolean
         */
        protected $_isPreview = false;
        
        /**
         * Is expired?
         *
         * @var boolean
         */
        protected $_isExpired = false;
        
        /**
         * Take position slug
         *
         * @var array
         */
        protected $_posSlug = array(
            1 => 'top-center',
            2 => 'top-left',
            3 => 'top-right',
            4 => 'bottom-center',
            5 => 'bottom-left',
            6 => 'bottom-right',
        );
        
        /**
         * Take style
         *
         * @var array
         */
        protected $_style = array(
            'style1',
            'style2',
            'style3',
            'style4',
            'style5',
        );
        
        /**
         * Class constructor
         *
         * @param  int|false $countdownId
         * @param  boolean   $isPreview
         * @return void
         */
        public function __construct( $countdownId = false, $isPreview = false )
        {
            $this->_prepare( $countdownId );
            $this->_isPreview = $isPreview;
        }
        
        /**
         * Set cookie for countdown time
         *
         * @return string
         */
        public function init()
        {
            global $post;
            
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return true;
            }
            $st = $this->_setting;
            
            //Check expired
            $type = $this->_setting->getSetting( 'time_type', '1' );
            if ( $type == 1 || $type == 2 ) {
                if ( empty( $this->_startCounter ) || $this->_startCounter < 0 ) {
                    $redirect = $st->getSetting( 'action_url' );
                    if ( ! empty( $redirect )) {
                        wp_redirect( $redirect );
                    }
                    $this->_isExpired = true;
                    return;
                }
            } else {
                if ( (int)$this->_visitLeft < 0 ) {
                    $redirect = $st->getSetting( 'action_url' );
                    if ( ! empty( $redirect )) {
                        wp_redirect( $redirect );
                    }
                    $this->_isExpired = true;
                    return;
                }
            }
            
            $type = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 || $type == 2 ) {
            
                $keycookie  = 'ipsp-countdown-' . $post->ID . '-time';
                if ( ! isset( $_COOKIE[$keycookie] )) {
                    setcookie( $keycookie, time(), time() + YEAR_IN_SECONDS, SITECOOKIEPATH );
                }
                
            } else {
            
                $keycookie = 'ipsp-countdown-' . $post->ID . '-visit';
                if ( ! isset( $_COOKIE[$keycookie] )) {
                    setcookie( $keycookie, 1, time() + YEAR_IN_SECONDS, SITECOOKIEPATH );
                } else {
                    $visit = $_COOKIE[$keycookie] + 1;
                    setcookie( $keycookie, $visit, time() + YEAR_IN_SECONDS, SITECOOKIEPATH );
                }
            }
            $keycookie = 'ipsp-countdown-' . $post->ID . '-id';
            if ( ! isset( $_COOKIE[$keycookie] )) {
                setcookie( $keycookie, $this->_countdown->ID, time() + YEAR_IN_SECONDS, SITECOOKIEPATH );
            }
        }
        
        /**
         * Create countdown
         *
         * @return string
         */
        public function create( $return = false )
        {
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return true;
            }
            if ( $this->_isExpired ) {
                return true;
            }
            $result  = '';
            $type    = $this->_setting->getSetting( 'countdown_type' );
            if ( $type == 1 ) {
            
                $style   = $this->_setting->getSetting( 'design_style' );
                if ( in_array( $style, $this->_style )) {
                    $func = '_get' . ucfirst( $style );
                    if ( method_exists( $this, $func )) {
                        $result = $this->$func();
                    }
                }
                if ( ! empty( $result )) {
                    if ( empty( $this->_position )) {
                        $this->_position = 1;
                    }
                    $result = $this->_addDeco( $result, $this->_position );
                }
            } else {
                    $result = $this->_getFloatingWidget();
            }
            if ( $return ) {
                return $result;
            } else {
                echo $result;
            }
        }
        
        /**
         * Get countdown style 1
         *
         * @return void
         */
        protected function _getStyle1()
        {
            $result  = '<div' . $this->_getContStyle() . '>
                            <div class="ipsp-inner clearfix">';
            
            $result .= $this->_getInfo();
            $result .= '<div class="ipsp-action clearfix">';
            
            $result .= $this->_getCounter();
            $result .= $this->_getButton();
            
            $result .= '</div>';
            $result .= '</div>';
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get countdown style 2
         *
         * @return void
         */
        protected function _getStyle2()
        {
            $result  = '<div' . $this->_getContStyle() . '>
                            <div class="ipsp-inner clearfix">';
            
            $result .= $this->_getInfo();
            $result .= '<div class="ipsp-action clearfix">';
            
            $result .= $this->_getCounter();
            $result .= $this->_getButton();
            
            $result .= '</div>';
            $result .= '</div>';
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get countdown style 3
         *
         * @return void
         */
        protected function _getStyle3()
        {
            $result  = '<div class="ipsp-outer clearfix"' . $this->_getContStyle() . '>
                            <div class="ipsp-inner">
                                <div class="ipsp-inner2 clearfix">';
            
            $result .= $this->_getInfo();
            $result .= '<div class="ipsp-action">
                            <div class="ipsp-action-inner clearfix">';
            
            $result .= $this->_getCounter();
            $result .= $this->_getButton();
            
            $result .= '    </div>
                        </div>';
            
            $result .= '    </div>
                        </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Get countdown style 4
         *
         * @return void
         */
        protected function _getStyle4()
        {
            $result  = '<div' . $this->_getContStyle() . '>
                            <div class="ipsp-inner clearfix">';
            
            $result .= $this->_getInfo();
            $result .= '<div class="ipsp-action clearfix">';
            
            $result .= $this->_getCounter();
            $result .= $this->_getButton();
            
            $result .= '</div>';
            $result .= '</div>';
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get countdown style 5
         *
         * @return void
         */
        protected function _getStyle5()
        {
            $result  = '<div' . $this->_getContStyle() . '>
                            <div class="ipsp-inner clearfix">';
            
            $result .= $this->_getInfo();
            $result .= '<div class="ipsp-action clearfix">';
            
            $result .= $this->_getCounter();
            $result .= $this->_getButton();
            
            $result .= '</div>';
            $result .= '</div>';
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get floating widget
         *
         * @return void
         */
        protected function _getFloatingWidget()
        {
            $st      = $this->_setting;
            $bgcolor = $st->getSetting( 'widget_bgcolor', '#000000' );
            $color   = $st->getSetting( 'widget_color', '#ffffff' );
            $font    = $st->getSetting( 'widget_font', 'Arial, sans-serif' );
            $style   = ' style="color: ' . $color . '; font-family: ' . $font . ';"';
            
            $result  = '<div class="ipsp-floating-widget"' . $style . '>
                            <div class="ipsp-inner">';
            
            $result .= $this->_getInfo( ' style="background-color: ' . $bgcolor . ';"' );
            $result .= '<div class="ipsp-action clearfix">';
            
            $result .= $this->_getCounter(true);
            
            $result .= '</div>';
            $result .= '</div>';
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get info
         *
         * @return void
         */
        protected function _getInfo( $style = '' )
        {
            $st      = $this->_setting;
            $content = $st->getSetting( 'initial-content', '' );
            $type    = $st->getSetting( 'time_type', '1' );
            $now     = time();
            $wcontent1 = $st->getSetting( 'warning-content-1' );
            $wcontent2 = $st->getSetting( 'warning-content-2' );
            $iclass    = '';
            if ( $type == 1 ) {
                
                $start   = $this->_startCounter;
                $w1time  = $this->_warning1Time;
                $w2time  = $this->_warning2Time;
                if ( ! empty( $wcontent2 ) && ( $start < $w2time )) {
                    $content = $wcontent2;
                    $iclass  = ' ipsp-warning2';
                } elseif ( ! empty( $wcontent1 ) && ( $start < $w1time )) {
                    $content = $wcontent1;
                    $iclass  = ' ipsp-warning1';
                }
            } elseif ( $type == 2 ) {
                
                $start   = time();
                $w1time  = $this->_warning1Time;
                $w2time  = $this->_warning2Time;
                if ( ! empty( $wcontent2 ) && ( $start > $w2time )) {
                    $content = $wcontent2;
                    $iclass  = ' ipsp-warning2';
                } elseif ( ! empty( $wcontent1 ) && ( $start > $w1time )) {
                    $content = $wcontent1;
                    $iclass  = ' ipsp-warning1';
                }
                
            } else {
                $visit     = $st->getSetting( 'visit_number' );
                $vwarning1 = $st->getSetting( 'wt1_visit' );
                $vwarning2 = $st->getSetting( 'wt2_visit' );
                
                if ( ! empty( $wcontent2 ) && ( $this->_visitLeft <= ( $visit - $vwarning2 ) )) {
                    $content = $wcontent2;
                    $iclass  = ' ipsp-warning2';
                } elseif ( ! empty( $wcontent1 ) && ( $this->_visitLeft <= ( $visit - $vwarning1 ) )) {
                    $content = $wcontent1;
                    $iclass  = ' ipsp-warning1';
                }
            }
            $result  = '<div class="ipsp-info-wrap'.$iclass.'">
                            <div class="ipsp-info"' . $style  . '>' . $content . '</div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Get button
         *
         * @return void
         */
        protected function _getButton()
        {
            $plgurl  = plugin_dir_url( dirname(__FILE__) );
            $st      = $this->_setting;
            $result  = '';
            if ( $st->getSetting( 'use_button' )) {
                $link    = $st->getSetting( 'button_link' );
                $design  = $st->getSetting( 'button_design', 'warning-buy-until-ins' );
                
                if ( $this->_position == 1 || $this->_position == 4 ) {
                } else {
                    $design = 'small-' . $design;
                }
                $style   = ' style="color: ' . $color . '; background-color: ' . $bgcolor . ';"';
                $label   = '<img src="' . $plgurl . 'img/button/' . $design . '.png" alt="Buy Now!">';
                
                $result  = '<div class="ipsp-button">
                                <a class="ipsp-btn-img" href="' . $link . '" ' . $style . '>' . $label . '</a>
                            </div>';
            }
            return $result;
        }
        
        /**
         * Get container style
         *
         * @return void
         */
        protected function _getContStyle()
        {
            $st      = $this->_setting;
            $bgcolor = $st->getSetting( 'design_bgcolor', '#000000' );
            $color   = $st->getSetting( 'design_color', '#ffffff' );
            $font    = $st->getSetting( 'design_font', 'Arial, sans-serif' );
            $style   = ' style="color: ' . $color . '; background-color: ' . $bgcolor . '; font-family: ' . $font . ';"';
            
            return $style;
        }
        
        /**
         * Get counter
         *
         * @return void
         */
        protected function _getCounter( $widget = false )
        {
            $result = '<div class="ipsp-counter-wrap">';
            
            $type   = $this->_setting->getSetting( 'time_type', '1' );
            if ( $type == 1 || $type == 2 ) {
                $result .= $this->_getCounterTime( $type, $widget );
            } else {
                $result .= $this->_getVisit();
            }
            $result .= '</div>';
            
            return $result;
        }
        
        /**
         * Get visit counter
         *
         * @return void
         */
        protected function _getVisit()
        {
            $visitLeft  = $this->_visitLeft;
            $visitText  = $this->_setting->getSetting( 'visit_text', '{visit_number} visits' );
            $visitText  = str_replace( '{visit_number}', $visitLeft, $visitText );
            $result    .= '<div class="ipsp-counter-visit">' . $visitText . '</div>';
            return $result;
        }
        
        /**
         * Get visit counter
         *
         * @return void
         */
        protected function _getVisitLeft()
        {
            global $post;
            
            $keycookie = 'ipsp-countdown-' . $post->ID . '-visit';
            if ( isset( $_COOKIE[$keycookie] )) {
                $visitNow = absint( $_COOKIE[$keycookie] );
                $visitNow++;
            } else {
                $visitNow = 1;
            }
            $visit = $this->_setting->getSetting( 'visit_number', 0 );
            $left  = $visit - $visitNow;
            return $left;
        }
        
        /**
         * Get counter code
         *
         * @return void
         */
        protected function _getCounterTime( $type, $widget = false )
        {
            global $post;
            
            $st     = $this->_setting;
            
            $count  = 0;
            $start  = $this->_startCounter;
            $dates = $this->_timeToDates( $start );
            extract( $dates );
            
            $type   = $st->getSetting( 'time_type', '1' );
            if ( $type == 2 ) {
                $fshow  = $st->getSetting( 'force_show_sp' );
            } else {
                $fshow  = $st->getSetting( 'force_show_dur' );
            }
            $starts = array();
            $labels = array();
            if ( ! empty( $day )) {
                if ( strlen( $day ) == 1 ) {
                    $day = "0$day";
                }
                $starts[] = $day;
                $labels[] = '<strong><span>' . __( 'Day' ) . '</span></strong>';
                $count++;
            } elseif ( $fshow ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Day' ) . '</span></strong>';
            }
            if ( ! empty( $hour )) {
                if ( strlen( $hour ) == 1 ) {
                    $hour = "0$hour";
                }
                $count++;
                $starts[] = $hour;
                $labels[] = '<strong><span>' . __( 'Hour' ) . '</span></strong>';
            } elseif ( ! empty( $day ) ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Hour' ) . '</span></strong>';
                $count++;
            } elseif ( $fshow ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Hour' ) . '</span></strong>';
            }
            if ( ! empty( $minute )) {
                if ( strlen( $minute ) == 1 ) {
                    $minute = "0$minute";
                }
                $count++;
                $starts[] = $minute;
                $labels[] = '<strong><span>' . __( 'Minute' ) . '</span></strong>';
            } elseif ( ! empty( $hour ) || ! empty( $day ) ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Minute' ) . '</span></strong>';
                $count++;
            } elseif ( $fshow ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Minute' ) . '</span></strong>';
            }
            if ( ! empty( $second )) {
                if ( strlen( $second ) == 1 ) {
                    $second = "0$second";
                }
                $count++;
                $starts[] = $second;
                $labels[] = '<strong><span>' . __( 'Second' ) . '</span></strong>';
            } elseif ( ! empty( $minute ) || ! empty( $hour ) || ! empty( $day ) ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Second' ) . '</span></strong>';
                $count++;
            } elseif ( $fshow ) {
                $starts[] = '00';
                $labels[] = '<strong><span>' . __( 'Second' ) . '</span></strong>';
            }
            $start_int = implode( $starts, ':' );
            
            if ( $fshow ) {
                $format = '99:23:59:59';
                $stop   = '00:00:00:00';
            } else {
                //Format
                $format = str_repeat( ':59', $count );
                $format = trim( $format, ':' );
                if ( $count == 4 ) {
                    $format = substr_replace( $format, '99', 0, 2 );
                    $format = substr_replace( $format, '99', 3, 2 );
                }
                if ( $count == 3 ) {
                    $format = substr_replace( $format, '23', 0, 2 );
                }
                //Stop
                $stop = str_repeat( ':00', $count );
                $stop = trim( $stop, ':' );
            }
            
            $counter = '';
            $script  = '';
            if ( ! $this->_isPreview ) {
            
                $redirect = $st->getSetting( 'action_url', '' );
                $confirm  = false;
                if ( $confirm ) {
                    $confirm = 'true';
                } else {
                    $confirm = 'false';
                }
                
                $step1     = 'false';
                $wcontent1 = $st->getSetting( 'warning-content-1' );
                if ( $wcontent1 && ! empty( $this->_warning1 ) && $this->_warning1 > 0 ) {
                    $step1 = '{
                        "text": "' . $wcontent1 . '",
                        "interval": "' . $this->_warning1*1000 . '",
                    }';
                }
                
                $step2     = 'false';
                $wcontent2 = $st->getSetting( 'warning-content-2' );
                if ( $wcontent2 && ! empty( $this->_warning2 ) && $this->_warning2 > 0 ) {
                    $step2 = '{
                        "text": "' . $wcontent2 . '",
                        "interval": "' . $this->_warning2*1000 . '",
                    }';
                }
                if ( $widget ) {
                    $funcname = 'ipsp_counterTextWidget';
                } else {
                    $funcname = 'ipsp_counterText';
                }
                $script = '$( ".ipsp-counter" ).'.$funcname.'({
                    "step1" : '.$step1.',
                    "step2" : '.$step2.',
                    "finish" : {
                        "interval" : ' . ($start*1000) . ',
                        "redirect" : "' . $redirect . '",
                        "confirm"  : ' . $confirm . ',
                    },
                });';
            }
            if ( ( $this->_position == 1 || $this->_position == 4 ) && ! $widget ) {
                $class = 'counter-standard';
            } else {
                $class = 'counter-medium';
            }
            $counter .= '</span>';
            $counter .= '<span class="ipsp-counter '.$class.'" data-format="' . $format .'" data-interval="1000" data-stop="' . $stop . '">' . $start_int . '</span>
<script type="text/javascript">
    jQuery(document).ready( function($) {
        $(".ipsp-counter").counter();
        ' . $script . '
    });
</script>';
            
            $counter .= '<span class="ipsp-counter-label">' . implode( $labels, '' ) . '</span>';
            return $counter;
        }
        
        /**
         * Get countdown top center
         *
         * @param  string $result
         * @param  int    $position
         *
         * @return void
         */
        protected function _addDeco( $result, $position )
        {
            $style = $this->_setting->getSetting( 'design_style' );
            $class = 'ipsp-cd ipsp-container ipsp-'.$style;
            if ( array_key_exists( $position, $this->_posSlug )) {
                $class .= ' ipsp-' . $this->_posSlug[$position];
            }
            $result = '<div class="' . $class . '">' .
                        $result .
                      '</div>';
            
            return $result;
        }
        
        /**
         * Prepare class
         *
         * @param  int|false $countdownId
         * @return void
         */
        protected function _prepare( $countdownid )
        {
            if ( ! $countdownid ) {
            
                global $post, $wp_query;
                
                //Try get countdown
                $countdownid = $position = 0;
                if ( ( is_page() || is_single() ) && ! empty( $post )) {
                    $metas = get_post_meta( $post->ID, '_ip_post_countdown' );
                    
                    if ( ! empty( $metas )) {
                        $meta = array_shift( $metas );
                        if ( ! empty( $meta['countdown_id'] )) {
                            $countdownid = absint( $meta['countdown_id'] );
                        }
                        if ( ! empty( $meta['position'] )) {
                            $position = absint( $meta['position'] );
                        }
                    }
                } elseif ( is_home() ) {
                    $opts        = get_option( '_ip_homepage_countdown' );
                    $countdownid = absint( $opts['countdown_id'] );
                    $position    = absint( $opts['position'] );
                }
            }
            if ( $countdownid ) {
                if ( $countdown = get_post( $countdownid)) {
                    $this->_countdown = $countdown;
                    $this->_setting   = new IPScarcityPlus_Setting( $countdown->ID );
                    
                    $type = $this->_setting->getSetting( 'time_type', '1' );
                    if ( $type == 1 || $type == 2 ) {
                        $this->_duration     = $this->_getDuration();
                        $this->_startTime    = $this->_getStartTime();
                        $this->_startCounter = $this->_getStartCounter( $this->_duration, $this->_startTime );
                        $this->_warning1Time = $this->_getWarning1Time();
                        $this->_warning2Time = $this->_getWarning2Time();
                        $this->_warning1     = $this->_getWarning1Duration( $this->_duration, $this->_warning1Time, $this->_startCounter );
                        $this->_warning2     = $this->_getWarning2Duration( $this->_duration, $this->_warning2Time, $this->_startCounter );
                    
                    } else {
                        $this->_visitLeft = $this->_getVisitLeft();
                    }
                    
                }
            }
            $this->_position = $position;
            
            return true;
        }
        
        /**
         * Get duration
         *
         * @return int
         */
        protected function _getDuration()
        {
            global $post;
            
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st   = $this->_setting;
            $time = 0;
            $type = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $day    = $st->getSetting( 'period_day', 0 );
                $hour   = $st->getSetting( 'period_hour', 0 );
                $minute = $st->getSetting( 'period_minute', 0 );
                $second = $st->getSetting( 'period_second', 0 );
                $time   = $day * 24 * 60 * 60;
                $time  += $hour * 60 * 60;
                $time  += $minute * 60;
                $time  += $second;
            
            } elseif ( $type == 2 ) {
                $day    = $st->getSetting( 'specific_day', 0 );
                $month  = $st->getSetting( 'specific_month', 0 );
                $year   = $st->getSetting( 'specific_year', 0 );
                $hour   = $st->getSetting( 'specific_hour', 0 );
                $minute = $st->getSetting( 'specific_minute', 0 );
                $second = $st->getSetting( 'specific_second', 0 );
                
                $date   = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minute . ':' . $second;
                $time   = get_gmt_from_date( $date, 'U' );
            }
            return $time;
        }
        
        /**
         * Get start Counter
         *
         * @param  int $duration
         * @param  int $startTime
         * @return int
         */
        protected function _getStartCounter( $duration, $startTime )
        {
            global $post;
            
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st    = $this->_setting;
            $start = 0;
            $type  = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $start = $duration - ( time() - $startTime );
            
            } elseif ( $type == 2 ) {
                $start = $duration - time();
            }
            return $start;
        }
        
        /**
         * Get warning 1 Time
         *
         * @return int
         */
        protected function _getWarning1Time()
        {
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st    = $this->_setting;
            $time  = 0;
            $type  = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $day    = $st->getSetting( 'wt1_duration_day', 0 );
                $hour   = $st->getSetting( 'wt1_duration_hour', 0 );
                $minute = $st->getSetting( 'wt1_duration_minute', 0 );
                $second = $st->getSetting( 'wt1_duration_second', 0 );
                $time   = $day * 24 * 60 * 60;
                $time  += $hour * 60 * 60;
                $time  += $minute * 60;
                $time  += $second;
            
            } elseif ( $type == 2 ) {
                $day    = $st->getSetting( 'wt1_date_day', 0 );
                $month  = $st->getSetting( 'wt1_date_month', 0 );
                $year   = $st->getSetting( 'wt1_date_year', 0 );
                $hour   = $st->getSetting( 'wt1_date_hour', 0 );
                $minute = $st->getSetting( 'wt1_date_minute', 0 );
                $second = $st->getSetting( 'wt1_date_second', 0 );
                
                $date   = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minute . ':' . $second;
                $time   = get_gmt_from_date( $date, 'U' );
            }
            return $time;
        }
        
        /**
         * Get warning 2 Time
         *
         * @return int
         */
        protected function _getWarning2Time()
        {
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st    = $this->_setting;
            $time  = 0;
            $type  = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $day    = $st->getSetting( 'wt2_duration_day', 0 );
                $hour   = $st->getSetting( 'wt2_duration_hour', 0 );
                $minute = $st->getSetting( 'wt2_duration_minute', 0 );
                $second = $st->getSetting( 'wt2_duration_second', 0 );
                $time   = $day * 24 * 60 * 60;
                $time  += $hour * 60 * 60;
                $time  += $minute * 60;
                $time  += $second;
            
            } elseif ( $type == 2 ) {
                $day    = $st->getSetting( 'wt2_date_day', 0 );
                $month  = $st->getSetting( 'wt2_date_month', 0 );
                $year   = $st->getSetting( 'wt2_date_year', 0 );
                $hour   = $st->getSetting( 'wt2_date_hour', 0 );
                $minute = $st->getSetting( 'wt2_date_minute', 0 );
                $second = $st->getSetting( 'wt2_date_second', 0 );
                
                $date   = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minute . ':' . $second;
                $time   = get_gmt_from_date( $date, 'U' );
            }
            return $time;
        }
        
        /**
         * Get warning 1 duration
         *
         * @param  int $duration
         * @param  int $time
         * @param  int $start
         * @return int
         */
        protected function _getWarning1Duration( $duration, $time, $start )
        {
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st    = $this->_setting;
            $wtime = 0;
            $type  = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $wtime  = ( $duration - $time ) - ( $duration - $start );
            } elseif ( $type == 2 ) {
                $wtime  = $time - time();
            }
            return $wtime;
        }
        
        /**
         * Get warning 2 Duration
         *
         * @param  int $duration
         * @param  int $time
         * @param  int $start
         * @return int
         */
        protected function _getWarning2Duration( $duration, $time, $start )
        {
            if ( empty( $this->_countdown ) || empty( $this->_setting )) {
                return false;
            }
            $st    = $this->_setting;
            $wtime = 0;
            $type  = $st->getSetting( 'time_type', '1' );
            if ( $type == 1 ) {
                $wtime = ( $duration - $time ) - ( $duration - $start );
            } elseif ( $type == 2 ) {
                $wtime = $time - time();
            }
            return $wtime;
        }
        
        /**
         * Get start time
         *
         * @return int
         */
        protected function _getStartTime()
        {
            global $post;
            
            $time = 0;
            $st   = $this->_setting;
            $type = $st->getSetting( 'period_time_start' );
            if ( $type == 1 ) {
                $day    = $st->getSetting( 'startsp_day', 0 );
                $month  = $st->getSetting( 'startsp_month', 0 );
                $year   = $st->getSetting( 'startsp_year', 0 );
                $hour   = $st->getSetting( 'startsp_hour', 0 );
                $minute = $st->getSetting( 'startsp_minute', 0 );
                $second = $st->getSetting( 'startsp_second', 0 );
                $date   = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minute . ':' . $second;
                $time   = get_gmt_from_date( $date, 'U' );
                
            } elseif( $type == 2 ) {
                $keycookie = 'ipsp-countdown-' . $post->ID . '-time';
                if ( ! isset( $_COOKIE[$keycookie] )) {
                    $time = time();
                } else {
                    $time = (int)$_COOKIE[$keycookie];
                }
            }
            return $time;
        }
        
        /**
         * Get time different
         *
         * @param  string int
         * @return array
         */
        protected function _timeToDates( $time )
        {
            $day = $hour = $minute = $second = 0;
            if ( $time > 0 ) {
                $oneday = 24*60*60;
                if ( $time > $oneday ) {
                    $day  = floor($time/$oneday);
                    $time = $time - ($day*$oneday);
                }
                $onehour = 60*60;
                if ( $time > $onehour ) {
                    $hour = floor($time/$onehour);
                    $time = $time - ($hour*$onehour);
                }
                if ( $time > 60 ) {
                    $minute = floor($time/60);
                    $time   = $time - ($minute*60);
                }
                if ( $time > 0 ) {
                    $second = $time;
                }
            }
            return array(
                'day'    => $day,
                'hour'   => $hour,
                'minute' => $minute,
                'second' => $second
            );
        }
    }
}
?>