/*!
 * JQuery Modal Box
 *
 * @Author: M Arif Mahthunisnaini (iznyn@yahoo.co.id)
 *
 */
(function($){

    $.loaderBox = function( options ) {
        
        //Configuration
        var defaults = {
            iconLoader      : 'img/loader.gif',
            loader          : false,
            boxWidth        : 500,
            boxHeight       : 160,
            boxTitle        : 'Action',
            boxContentId    : 'pageActionBoxMain',
            boxId           : 'pageActionBox',
            
            escCancel       : true,
            buttonCancel    : true,
            cancelText      : 'X',
            draggable       : false,
            bgClickClose    : true,
            createBoxTitle  : true,
            boxContentPos   : 'fixed',
            
            appendLoader : function( box ){
                var content = $( '<div class="boxContent"></div>' );
                content.append( loader );
                box.append( content );
            },
            
            afterLoader       : function(){},
            ajaxContent       : true,
            appendAjaxContent : function(){},
            afterAjaxContent  : function(){},
            modalClose        : function(){},
        };
        var options = $.extend( defaults, options );
        
        //Build loader
        if ( ! options.loader ) {
            var loader = '<div class="loader"><img src="'+options.iconLoader+'" alt=""></div>';
        } else {
            var loader = options.loader;
        }
        //Action Box
        var actionBox = new $.actionBox(options);
        actionBox.showActionBox();
        
        var contBox = $( '#'+options.boxId );
        contBox.css( 'z-index', '99999' );
        contBox.addClass( 'loading' );
        //Reposition box
        $.repositionBox( contBox, options );
        
        //Is box draggable?
        if ( options.draggable ) {
            contBox.draggable();
        }
        
        var contentBox = $( '#'+options.boxContentId );
        contentBox.html('');
        
        if ( options.createBoxTitle ) {
            //Box title
            contentBox.prepend( '<div class="boxTitle">'+options.boxTitle+'</div>' );
        }
        
        //Append loader
        options.appendLoader( contentBox );
        
        //After append loader
        options.afterLoader();
        
        //Display content
        if ( options.ajaxContent ) {
            
            options.appendAjaxContent();
            
            var pageWidth  = $( 'html' ).width();
            var winHeight  = $(window).height();
            var scrollTop  = $(window).scrollTop();
            var contBox = $( '#'+options.boxId );
            
            contBox.height( 'auto' );
            contentHeight  = $( '#'+options.boxId ).height();
            contentTop     = scrollTop + (winHeight - contentHeight)/2;
            contBox.css( 'top', contentTop );
            contBox.removeClass( 'loading' );
            
            $.repositionBox( contBox, options );
            
            options.afterAjaxContent();
        };
        
        //Button cancel
        if ( options.buttonCancel ) {
            var cancel = $( '<a class="cancelLink" href="#">' + options.cancelText + '</a>' );
            cancel.click( function(){
                
                options.modalClose();
                actionBox.hideActionBox();
            });
            $( '<div class="btnCancel"></div>' ).append( cancel ).appendTo( $('#'+options.boxContentId) );
        };
        
        //Keybord cancel
        if ( options.escCancel ) {
            $(document).keydown( function(e) {
                if ((e.which || e.keyCode) === 27) {
                
                    options.modalClose();
                    actionBox.hideActionBox();
                }
            });
        };
        
        //Window change
        $(window).resize( function(){
            var contBox = $( '#'+options.boxId );
            $.repositionBox( contBox, options );
            actionBox.reposition();
        });
        
        //Bg click
        if ( options.bgClickClose ) {
            $( '#pageActionBoxBg' ).addClass( 'clickClose' );
            $( '#pageActionBoxBg' ).click( function(){
                
                actionBox.hideActionBox();
                options.modalClose();
            });
        };
    };
    
    /**
     * Reposition box
     **/
    $.repositionBox = function( box, options ) {
        
        var pageWidth = $( 'html' ).width();
        var winHeight = $(window).height();
        var scrollTop = $(window).scrollTop();
        
        box.height( 'auto' );
        
        var boxWidth  = options.boxWidth;
        var boxHeight = box.height();
        
        if ( pageWidth < boxWidth ) {
            boxWidth = 0.8 * pageWidth;
        }
        
        if ( winHeight < boxHeight ) {
            boxHeight = 0.8 * winHeight;
            titleHeight = $( '.boxTitle' ).height();
            $( '.boxContent' ).css( 'overflow', 'auto' );
            $( '.boxContent' ).css( 'height', boxHeight - titleHeight );
        } else {
            $( '.boxContent' ).attr( 'style', '' );
        }
        var boxTop    = (winHeight - boxHeight)/2;
        var boxLeft   = (pageWidth - boxWidth)/2;
        if ( boxLeft < 0 ) {
            boxLeft = 0;
        }
        
        box.width( boxWidth );
        box.css( 'top', boxTop );
        box.css( 'left', boxLeft );
        
    };
    
    /**
     * Action box
     **/
    $.actionBox = function( options ){
        
        //Configuration
        var defaults = {
            boxBgColor      : '#000000',
            boxBgOpacity    : '0.8',
            boxBgId         : 'pageActionBoxBg',
            boxId           : 'pageActionBox',
            boxContentId    : 'pageActionBoxMain',
            boxClass        : 'style_default',
            siteContId      : 'wrapper',
            boxContentPos   : 'fixed',
        };
        var options = $.extend( defaults, options );
        
        function _getActionBox() {
            
            var box = $('<div id="'+options.boxId+'" class="'+options.boxClass+'"></div>');
            box.css('position', options.boxContentPos);
            box.css('z-index', '99990');
            
            var inner = $( '<div class="boxDeco"><div class="boxInner"><div id="'+options.boxContentId+'"></div></div></div>' );
            box.append( inner );
            return box;
        };
        
        function _getActionBoxBg() {
        
            var boxBg = $('<div id="'+options.boxBgId+'"></div>');
            
            //Reposition box
            reposActionBox( boxBg );
            
            boxBg.css('background-color', options.boxBgColor);
            boxBg.css('opacity', options.boxBgOpacity);
            boxBg.css('position', 'fixed');
            boxBg.css('top', '0');
            boxBg.css('left', '0');
            boxBg.css('z-index', '99994');
            
            return boxBg;
        };
        
        this.getActionBox = function() {
        
            return _getActionBox();
        };
        
        this.getActionBoxBg = function() {
        
            return _getActionBoxBg();
        };
        
        this.showActionBox = function() {
        
            this.hideActionBox();
            
            $('body').css( 'opacity', 0 );
            $('body').append( this.getActionBox() ).animate({
                opacity: 1,
                }, 700 
            );
            $('body').append( this.getActionBoxBg() );
        };
    
       this.hideActionBox = function(){
        
            $( '#'+options.boxId ).animate({
                opacity: 0,
                }, 500, function() {
                    $( '#'+options.boxId ).remove();
                    $( '#'+options.boxBgId ).remove();
                    $( '#'+options.siteContId+'~div' ).remove();
            });
        };
    
       this.reposition = function(){
            
            var box = $('#'+options.boxBgId);
            reposActionBox( box )
        };
        
        function reposActionBox( box ) {
        
            var pageHeight = $( window ).height();
            var pageWidth  = $( window ).width();
            box.height( pageHeight );
            box.width( pageWidth );
        
        };
    };

    $.fn.modalElement = function(options) {
        
        var defaults  = {
            boxId : 'pageActionBox',
            modalProcess: function(){}
        };
        var options = $.extend( defaults, options );
        
        var link  = $(this);
        link.click( function() {
        
            var href  = link.attr( 'href' );
            var title = link.attr( 'title' );
            
            options.boxTitle     = title;
            options.ajaxContent  = false;
            options.appendLoader = function( box ){
                var content = $( '<div class="boxContent"></div>' );
                var element = $( href ).show();
                
                content.append( element );
                box.append( content );
                options.modalProcess();
                
                var contentBox = $( '#'+options.boxId );
                $.repositionBox( contentBox, options );
            };
            options.modalClose = function(){
            
                var element = $( href ).clone().hide();
                $( 'body' ).append( element );
            };
            
            //Main
            $.loaderBox(options);
           
            return false;
        });
    };

    $.fn.modalConfirm = function(options) {
    
        
        var defaults  = {
            boxWidth        : 450,
            boxHeight       : 170,
            boxContentId    : 'pageActionBoxMain',
            boxId           : 'pageActionBox',
            buttonCancel    : false,
            bgClickClose    : false,
            info            : 'Are you sure?',
            okButton        : true,
            cancelButton    : true,
            cancelLabel     : 'Cancel',
            okLabel         : 'Ok',
            cancelClass     : 'btn',
            okClass         : 'btn',
            cancelFunc      : function(){
                var actionBox = new $.actionBox(options);
                actionBox.hideActionBox();
            },
            okFunc          : function(){
            },
        };
        var options = $.extend( defaults, options );
        
        options.appendLoader = function( box ){
            var mainBox = $( '#'+options.boxContentId );
            var modal   = $( '<div class="modalConfirm"></div>' )
                                .append( '<div class="modalInfo">'+options.info+'</div>' );
            
            var modalAct =  $( '<div class="modalAction"></div>' );
            
            if ( options.okButton ) {
            
                var ok = $( '<a href="#"></a>' )
                                .addClass( options.okClass )
                                .text( options.okLabel )
                                .click( function(){
                                    options.okFunc();
                                    return false;
                                });
                
                modalAct.append( ok );
            }
            
            if ( options.cancelButton ) {
            
                var cancel  = $( '<a href="#"></a>' )
                                .addClass( options.cancelClass )
                                .text( options.cancelLabel )
                                .click( function(){
                                    options.cancelFunc();
                                    return false;
                                });
                
                modalAct.append( cancel );
            }
            mainBox.html( modal.append( modalAct ) );
                
            var contentBox = $( '#'+options.boxId );
             $.repositionBox( contentBox, options );
        };
            
        //Main
        $.loaderBox(options);
    };
    
})(jQuery);